==> code-highlight-4.5.3.tgz: package/README.md <==
# Rtdui code-highlight component

[![NPM license](https://img.shields.io/npm/l/@rtdui/code-highlight)](https://github.com/rtdui/rtdui/blob/main/LICENSE)
[![GitHub contributors](https://img.shields.io/github/contributors/rtdui/rtdui)](https://github.com/rtdui/rtdui/graphs/contributors)
[![NPM version](https://img.shields.io/npm/v/@rtdui/code-highlight)](https://www.npmjs.com/package/@rtdui/code-highlight)
[![NPM downloads](https://img.shields.io/npm/dm/@rtdui/code-highlight)](https://www.npmjs.com/package/@rtdui/code-highlight)
[![Help wanted](https://img.shields.io/github/labels/rtdui/rtdui/help%20wanted?label=Contribute)](https://github.com/rtdui/rtdui/labels/help%20wanted)

## Links

- [Documentation](https://rtdui.com/)
- [Ask question or give feedback](https://github.com/rtdui/rtdui/discussions)
- [Changelog](https://rtdui.com/changelog/previous-versions)

## Packages

This monorepo with a collection of packages:

- `@rtdui/hooks` – collection of 50+ hooks for state and UI management
- [`@rtdui/core`](https://rtdui.com/) – core components library – 100+ components, exports everything from `@rtdui/core`
- [`@rtdui/code-highlight`](https://rtdui.com/components/codehighlight) – code highlight built with `prism.js`
- [`@rtdui/dates`](https://rtdui.com/components/dates_about) – date,time,datetime,month,year pickers
- [`@rtdui/datatable`](https://rtdui.com/components/datatable_about) – a fully featured data table
- [`@rtdui/dialogs`](https://rtdui.com/components/dialog) – a fully featured dialogs system
- [`@rtdui/notifications`](https://rtdui.com/components/notification) – a fully featured notifications system
- [`@rtdui/editor`](https://rtdui.com/components/editor) – a Tiptap based rich text editor
- [`@rtdui/qr-code`](https://rtdui.com/components/qrcode) – qr code generator
- [`@rtdui/signature-pad`](https://rtdui.com/components/signaturepad) – signature pad
- [`@rtdui/tailwind-plugin`](https://rtdui.com/install) – tailwindCSS plugin

## Contributors

<a href="https://github.com/rtdui/rtdui/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=rtdui/rtdui" />
</a>

## License

MIT

==> code-highlight-4.9.5.tgz: package/README.md <==
# Rtdui code-highlight component

[![NPM license](https://img.shields.io/npm/l/@rtdui/code-highlight)](https://github.com/rtdui/rtdui/blob/main/LICENSE)
[![GitHub contributors](https://img.shields.io/github/contributors/rtdui/rtdui)](https://github.com/rtdui/rtdui/graphs/contributors)
[![NPM version](https://img.shields.io/npm/v/@rtdui/code-highlight)](https://www.npmjs.com/package/@rtdui/code-highlight)
[![NPM downloads](https://img.shields.io/npm/dm/@rtdui/code-highlight)](https://www.npmjs.com/package/@rtdui/code-highlight)
[![Help wanted](https://img.shields.io/github/labels/rtdui/rtdui/help%20wanted?label=Contribute)](https://github.com/rtdui/rtdui/labels/help%20wanted)

## Links

- [Documentation](https://rtdui.com/)
- [Ask question or give feedback](https://github.com/rtdui/rtdui/discussions)
- [Changelog](https://rtdui.com/changelog/previous-versions)

## Packages

This monorepo with a collection of packages:

- `@rtdui/hooks` – collection of 50+ hooks for state and UI management
- [`@rtdui/core`](https://rtdui.com/) – core components library – 100+ components, exports everything from `@rtdui/core`
- [`@rtdui/code-highlight`](https://rtdui.com/components/codehighlight) – code highlight built with `prism.js`
- [`@rtdui/dates`](https://rtdui.com/components/dates_about) – date,time,datetime,month,year pickers
- [`@rtdui/datatable`](https://rtdui.com/components/datatable_about) – a fully featured data table
- [`@rtdui/dialogs`](https://rtdui.com/components/dialog) – a fully featured dialogs system
- [`@rtdui/notifications`](https://rtdui.com/components/notification) – a fully featured notifications system
- [`@rtdui/editor`](https://rtdui.com/components/editor) – a rich text editor
- [`@rtdui/md-editor`](https://rtdui.com/components/mdeditor) – a Markdown editor component like VSCode built-in markdown editor and a viewer component for rendering markdown
- [`@rtdui/qr-code`](https://rtdui.com/components/qrcode) – qr code generator
- [`@rtdui/signature-pad`](https://rtdui.com/components/signaturepad) – signature pad
- [`@rtdui/tailwind-plugin`](https://rtdui.com/install) – tailwindCSS plugin

## Contributors

<a href="https://github.com/rtdui/rtdui/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=rtdui/rtdui" />
</a>

## License

MIT
